@@ -30,6 +30,7 @@
 #include "SDL_mixer.h"
 #endif
 #include "levels.h"
+#include "levels2.h"
 #include "particles.h"
 #include "menu.h"
 #include "bumprace.h"
@@ -46,7 +47,7 @@
     //the players
        player user[MAX_PLAYER_NUM]; int pl=0,playernum=2;
     //general setting
-       int final=1,fullscreen=1,pageflip=0,sound=1,precision=10,fps=0,particle=1,mode,dofadeout=1;
+       int final=1,fullscreen=1,pageflip=0,sound=1,precision=10,fps=0,particle=1,mode,dofadeout=1,levelset=0;
     //level settings
        float gravity=0,turbo=5,laser_switch;
        int startx,starty;
@@ -777,6 +778,8 @@ void ReadCommandLine(char *argv[])
     if ((strcmp(argv[i],"--nofadeout")==0)||(strcmp(argv[i],"-o")==0)) {dofadeout=0;} else
     if ((strcmp(argv[i],"--precision")==0)&&(argv[i+1])) 
       {i++;precision=atoi(argv[i]);printf("Precision is set to %d\n",precision);} else
+    if ((strcmp(argv[i],"--levelset")==0)&&(argv[i+1])) 
+      {i++;levelset=atoi(argv[i]);printf("Levelset is set to %d\n",levelset);} else
     if ((strcmp(argv[i],"--help")==0)||(strcmp(argv[i],"-h")==0)) TextHelp(argv);
     else  {
 	printf("Unknown parameter (-h for help): \"%s\" \n", argv[i]);
@@ -789,6 +792,8 @@ void BlitMenu()  //blits menu for SelectRacer
 {
   SDL_Rect fillrect;
 
+  NullParticle = 0;
+
   for (i=0;i<=5;i++)
   {
     if (i==user[pl].racernum) {
@@ -858,7 +863,10 @@ void nextlevel() //selects the next level at random
       finished[i]=0;
       for (x=0; x<20; x++) {
         for (y=0; y<15; y++) {
-          map[i][y][x] = origMap[i][y][x];
+	  if (levelset == 0)
+            map[i][y][x] = origMap[i][y][x];
+	  else 
+            map[i][y][x] = origMap2[i][y][x];
         }
       }
     }
@@ -881,12 +889,30 @@ void InitLevel()
   cannon.shot_delay=11000-Stage*300-abrand(0,3000+Stage*1000); cannon.time_to_shot=1000;
   laser_switch=6000+abrand(-Stage*500,200);
   cannon.type=abrand(1,5);
+  
+  if (levelset == 0) {
+  
   if (levelnum==12) {gravity=1;starty=560;} else {gravity=0;}
   if (levelnum==13) {starty=270;} 
   if (levelnum==14) {startx=370;starty=290;} 
   if (levelnum==15) {startx=750;starty=40;} 
   if (levelnum==16) {startx=370;starty=50;} 
   if (levelnum==17) {startx=370;starty=570;gravity=0.3;} 
+ 
+  } else {
+ 
+  if (levelnum==0) {startx=20;starty=570;gravity=1;}  else {gravity=0;}
+  if (levelnum==1) {startx=20;starty=20;} 
+  if (levelnum==2) {startx=20;starty=20;} 
+  if (levelnum==3) {startx=750;starty=470;gravity=0.5;} 
+  if (levelnum==4) {startx=5;starty=5;} 
+  if (levelnum==5) {startx=10;starty=10;gravity=0.3;} 
+  if (levelnum==6) {startx=10;starty=20;gravity=1.5;} 
+  if (levelnum==7) {startx=20;starty=570;gravity=1.5;}
+  if (levelnum==8) {startx=20;starty=570;gravity=0;}
+	
+  }
+  	     
   for (pl=0;pl<playernum;pl++)
   {
     user[pl].realx=startx+10*pl;user[pl].realy=starty;user[pl].xspeed=0;user[pl].yspeed=0;
@@ -971,24 +997,33 @@ void InitSound()
     fprintf(stderr,"Warning: Couldn't set 22025 Hz 16-bit audio\n- Reason: %s\n",SDL_GetError());
     fprintf(stderr,"\t**\nSOUND TURNED OFF\n\t**\n");
     sound=0;
-  }else{  
-    sprintf(text,"%s/sound/lizard.mod",DATAPATH);
-    music = Mix_LoadMUS(text);
-    if (music==NULL) {printf("COULD NOT LOAD MUSIC\n");ComplainAndExit();}
-    sprintf(text,"%s/sound/%s",DATAPATH,"explode.wav");
-    explode_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
-    sprintf(text,"%s/sound/%s",DATAPATH,"winlevel.wav");
-    winlevel_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
-    sprintf(text,"%s/sound/%s",DATAPATH,"whoosh.wav");
-    teleport_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
   }
 }
+
+void LoadSound()
+{
+	if ( SDL_Init(SDL_INIT_AUDIO) < 0 ) {ComplainAndExit();}
+	if (sound) {
+		sprintf(text,"%s/sound/lizard.mod",DATAPATH);
+		music = Mix_LoadMUS(text);
+		if (music==NULL) {printf("COULD NOT LOAD MUSIC\n");ComplainAndExit();}
+		sprintf(text,"%s/sound/%s",DATAPATH,"explode.wav");
+		explode_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
+		sprintf(text,"%s/sound/%s",DATAPATH,"winlevel.wav");
+		winlevel_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
+		sprintf(text,"%s/sound/%s",DATAPATH,"whoosh.wav");
+		teleport_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
+	}
+}
 #endif
 
 main(int argc, char *argv[])
 {
 //intialisation
   ReadCommandLine(argv);
+#ifdef SOUND
+  if (sound) {InitSound();}
+#endif
   init_SDL();
   SDL_ShowCursor(0);
   SDL_WM_SetCaption("BumpRace","BumpRace");
@@ -1012,8 +1047,10 @@ main(int argc, char *argv[])
 //load data
   printf("** Loading Data **\n");
 #ifdef SOUND
-  if (sound) {InitSound();}
-  if ((!Mix_PlayingMusic())&&(sound)) {Mix_PlayMusic(music,1);}				
+  if (sound) {
+	  LoadSound();
+	  if (!Mix_PlayingMusic()) {Mix_PlayMusic(music,1);}
+  }
 #endif
   load_images();
   printf("** Main data loaded **\n");
@@ -1027,7 +1064,10 @@ main(int argc, char *argv[])
     finished[i]=0;
     for (x=0; x<20; x++) {
 	for (y=0; y<15; y++) {
-	    map[i][y][x] = origMap[i][y][x];
+	    if (levelset == 0)
+		map[i][y][x] = origMap[i][y][x];
+	    else
+		map[i][y][x] = origMap2[i][y][x];
 	}
     }
   }
